Description Usage Arguments Value
This function allows you to do variational Bayesian inference for Gaussian mixture.
1 |
X |
NxD data matrix |
K |
Number of mixture components |
init |
Initialisation method (optional). If it is a vector, it is interpreted as the vector of initial cluster allocations. If it is a string, it is interpreted as the name of the clustering algorithm used for the initialisation (only "kmeans" and "random") available at the moment). |
verbose |
Boolean flag which, if TRUE, prints the type of initialization |
Resp NxK matrix of responsibilities
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.